@@ -591,53 +591,56 @@ def get_ebs_daily_breakdown(days: int = 30, specific_date: str = None, month: st
         client = get_ce_client()
         start_date, end_date = parse_date_params(days, specific_date, month)
         
+        # Use the exact same filter as the AWS CLI command
         request_params = {
             'TimePeriod': {
                 'Start': start_date.strftime('%Y-%m-%d'),
                 'End': end_date.strftime('%Y-%m-%d')
             },
-            'Granularity': 'DAILY',
+            'Granularity': 'MONTHLY',
             'Metrics': ['BlendedCost'],
-            'GroupBy': [
-                {'Type': 'DIMENSION', 'Key': 'SERVICE'},
-                {'Type': 'DIMENSION', 'Key': 'USAGE_TYPE'}
-            ]
+            'GroupBy': [{'Type': 'DIMENSION', 'Key': 'USAGE_TYPE'}],
+            'Filter': {
+                'Dimensions': {
+                    'Key': 'SERVICE',
+                    'Values': ['EC2 - Other']
+                }
+            }
         }
         
-        # Add region filter if specified (skip for 'all', 'global', or empty values)
+        # Add region filter if specified (combine with service filter)
         if filter_region and filter_region not in ['all', 'global', '']:
             request_params['Filter'] = {
-                'Dimensions': {
-                    'Key': 'REGION',
-                    'Values': [filter_region]
-                }
+                'And': [
+                    {
+                        'Dimensions': {
+                            'Key': 'SERVICE',
+                            'Values': ['EC2 - Other']
+                        }
+                    },
+                    {
+                        'Dimensions': {
+                            'Key': 'REGION',
+                            'Values': [filter_region]
+                        }
+                    }
+                ]
             }
         
         response = client.get_cost_and_usage(**request_params)
         
-        # Process the response - capture ALL EBS usage types
-        ebs_costs = {}
+        # Process the response - capture ALL EC2-Other usage types
+        ec2_other_costs = {}
         
         for result in response['ResultsByTime']:
             for group in result['Groups']:
-                service = group['Keys'][0]
-                usage_type = group['Keys'][1]
+                usage_type = group['Keys'][0]
                 cost = float(group['Metrics']['BlendedCost']['Amount'])
-                
-                # Capture ALL usage types with any measurable cost (EBS and non-EBS gp3)
-                if cost >= 0.0001:
-                    if 'EBS:' in usage_type:
-                        # Standard EBS usage types
-                        clean_type = usage_type.replace('EBS:', '').strip()
-                        display_name = f'EBS {clean_type}'
-                        ebs_costs[display_name] = ebs_costs.get(display_name, 0) + cost
-                    elif 'gp3' in usage_type.lower() and ('provisioned' in usage_type.lower() or 'throughput' in usage_type.lower() or 'iops' in usage_type.lower()):
-                        # Capture gp3 provisioned charges that might not have EBS: prefix
-                        display_name = f'EBS {usage_type}'
-                        ebs_costs[display_name] = ebs_costs.get(display_name, 0) + cost
+                if cost > 0:
+                    ec2_other_costs[usage_type] = ec2_other_costs.get(usage_type, 0) + cost
         
         breakdown = [{'category': cat, 'cost': cost} 
-                    for cat, cost in sorted(ebs_costs.items(), key=lambda x: x[1], reverse=True)]
+                    for cat, cost in sorted(ec2_other_costs.items(), key=lambda x: x[1], reverse=True)]
         return {'breakdown': breakdown}
         
     except Exception as e:
